
# q-expansion of newform 105.10.a.f, downloaded from the LMFDB on 26 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 105
weight = 10
poly_data = [8836, -270, -307, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, 2, 0, 0], 1], [[258, -246, -3, 1], 1], [[-614, -6, 4, 0], 1]]

hecke_ring_character_values = None
aps_data = [[2, -1, 0, 0], [81, 0, 0, 0], [-625, 0, 0, 0], [-2401, 0, 0, 0], [2458, -1745, -41, 16], [-17066, -1908, 49, 3], [21568, 167, 356, 495], [201918, -7793, -155, 990], [170758, -26785, 636, 107], [1257328, -18877, 52, 1531], [2450748, -154290, -3435, -4563], [-1134108, -201799, 4378, -10089], [2770250, -381950, -2384, -24218], [-8610562, -85193, 8050, -14403], [-9807542, 445487, -7478, -38039], [19003132, 1074285, -9839, 11424], [18648856, 198302, 34474, 146520], [25311648, -257341, -87764, 14463], [-11423566, 3660277, 6628, -177471], [111796900, 6474180, -6591, -3785], [35381906, 1581448, 98427, -373371], [197414784, -3552532, 44094, -161254], [146570588, 7829556, 132666, -916838], [262557522, 2156742, -762920, -22542], [197015322, 5154120, -792923, -651989], [311390630, 25660678, 353584, 1568110], [882930224, 483808, 968104, 631360], [916467734, 7823985, 1742022, 2045855], [543596950, -10573556, -111088, 1454300], [-455185900, 35896887, 306645, -2677070], [302932508, -63057922, 1368890, 3089348], [2040362504, 126965558, -2425008, 472946], [-1673514212, -33274485, -991781, -9567424], [-3684663002, -25564301, 4412281, -1121578], [1271360480, 158385827, 33194, 4427845], [521743236, 210852442, -2818536, -1538234], [-1660671378, -117843084, -2088697, 16390133], [-2023845414, 332191001, -550770, -3826285], [-1186820610, -75773967, -7164892, -5160807], [4159113782, -16161446, -2355378, 8992596], [5509616074, -15276209, 3756671, 6776664], [-9794263788, 503426873, 409826, -4772017], [-3433745732, 899433988, -2238389, -2694995], [1988609398, 23756366, 13806256, 7424606], [-8028805524, 145217133, 13134791, -7560278], [-8422126156, 114744386, 9736377, -14599763], [-12252484632, 409133590, -28095094, -40422784], [1831993620, -1476346962, 11714642, 46959332], [7343890628, -1011084868, 25183366, -15372746], [30322524768, -559059277, -42144168, -16266717], [14708020040, -484807627, 1220337, -81274340], [59754808804, 178976708, 36394041, 37266751], [-5805623954, 1692079462, 44992614, 35264440], [23517265804, -1646866852, -2178738, 29635842], [8722264008, -871373361, -9063482, -160759979], [-10676778070, -825404675, 58810510, -10902209], [105378630770, 884788056, 14025756, 10740428], [-2216579020, 2534410418, 28341931, 112747827], [-16767232864, 558863403, 25247758, 263682237], [33347191958, 2226631518, -462370, 75247576], [-30615333436, -2072889856, -124531976, -72308616], [78223702570, -4986318108, -72730818, -140385962], [-54353817396, -2050115872, 212170510, 13594066], [-12618578168, -1309956476, 65943252, -313298968], [48570818670, 2628720238, 116834553, -39426043], [48642052140, -1867853503, -110968371, 241493736], [-131490831576, 1389042098, 46756870, -72794712], [-10611747834, 10655748766, 97465788, 72626642], [-293846615730, 353358225, -96176764, -4512303], [147691628892, -10172489819, -51825912, -624024107], [111734682660, -7700018227, -31684392, -274447959], [51504525208, 4503650626, 92817527, 509085911], [-14320192096, 1793121680, 18674290, 690163126], [133723545812, -9305918175, 114803364, -18587707], [60727959816, -4964103462, -123066964, -480021318], [-15457268746, 718196909, 250044164, -885286931], [-36856667676, -6758396963, -147734918, 316648391], [112552097346, 2574248626, -413531075, -23962787], [-272105743090, -3138620778, 127908208, -254618346], [241079395166, 11396094818, 67551332, 902467718], [152834243328, -240894602, 304513548, -521572514], [105575493230, 10552645644, 210015360, -1527741324], [-364641353644, -2521648784, -457322127, -1081201173], [470372088582, 25674782022, -348419131, -475085407], [850961872296, 16867425472, 147857117, -36127881], [529818071142, 9994427829, -221291532, 1182918397], [678504435998, -9303600958, 257873504, -240918134], [-414534996814, 20445454524, -271745374, -1429142198], [580562236398, -14369417530, -79645780, 778908722], [935342742632, 17242487496, 553310974, -966261934], [54639350368, -11109081018, 583640114, 936147332], [-88643245968, -1358546524, -550660324, -462968296], [16049528152, 6112109024, -1563416862, -828557802], [77602885490, -35412276857, 226246455, -3043111224], [305263298624, 14519379346, -591609780, -1494470158], [195685968346, -11369875689, -492102452, 2077548335], [409578606962, -14959029840, -595031900, -3968211892], [-513240496162, -15198941204, 1157812820, 2011310532], [143695695660, -14419915232, 917171634, -2343005554], [-1594260041534, 30548981438, 179950308, -1116041694], [513131949858, -40814038251, -193862000, 4131465389], [-557239420764, -20100586659, 463529329, 5179652584], [-2602524158396, 17760559196, 824471980, -1038296848], [-208172067626, -102327295754, 332686588, 965947578], [-1584263669424, 106100243842, 2048457168, 3633024534], [-1794714012322, 90164764786, 836680697, 2813409193], [-137184406044, -59067109544, -3964437680, -3503216576], [1355757631584, 4720112471, -2925088800, -1022987253], [371670598884, 34037094516, -260227469, -2278049459], [-496082404438, 181000207904, -1892737366, 88631990], [1356963733916, -9721281470, -255030622, -7228639552], [-3049443037124, -39138776675, 36105506, -156136957], [1171052806416, 8163962481, 1394449837, 3107165740], [-1314022590782, 51152855485, 774826889, -88706848], [-2617073888868, 120891833338, -3900565118, -5513099836], [-522086959646, 182943017700, 950960958, -1044732666], [-2150726295848, 8059064946, 1879183286, 4516811260], [-55406493278, -40572724233, 3854778656, 4347423867], [1266545737264, 45372058315, -5209733709, -287677012], [1026402399426, -153385465697, 3929157337, 3788920182], [-3892370010088, 49338692147, -3628600776, -1972107821], [-1276807485954, -291721935462, 2622485470, 3775815644], [1889676258206, -79165816462, -1342477738, -10066143548], [-652410631494, 154492641755, -2708126120, 9560080767], [341467488706, 92847358345, 1812144607, 6835888574], [777780219728, -73959071709, -2376996260, -15312430381], [-2770475259942, -210637553466, 1507066288, 7458408926], [2667980557636, 129596981286, -1198718074, 9088768488], [6229557738216, 1931584012, 467875806, -979349242], [-1411388695066, 58566080396, 1539589501, -4270193145], [-4744860176996, -88032544744, -4277336244, -2397817936], [3548032956666, 85702346105, 3742013886, -10515465181], [-1675867820712, 238384132916, 8894570762, 8956468022], [1674501732588, 103929886853, -2895860096, 1475281813], [2362071954494, 80858565136, 5371314252, 2265713056], [-5941742354522, -14443374426, -3504324598, -7984663588], [1487603966154, 223031130780, -1344279338, 15042753270], [5001479271608, 127496916798, -8439274342, 3788592084], [4385842861742, 104562234886, 7751893022, -10867474976], [-9680308837294, 248084931524, -1504527654, 11846103874], [2073532545158, -209809021309, -6264874695, 5154270918], [3195587369308, 217687818797, -2995569404, 20389899949], [-4705587074096, -454979044816, -9256455426, 12923966858], [5810383793762, 90582748155, -3861442014, 11962252621], [-8344242414744, 465818103763, 11567012038, 14340819509], [412351566300, -596571132414, 7855053026, 1573814824], [-12080730178310, -164667201046, 13451657593, 6954209273], [-5294866931352, -29627038261, 11221089554, 16783563661], [-11158874908170, 95562062015, -8118888117, -17230802576], [-786276812894, 444994887413, 1917236168, -28979713899], [7132762235128, 310235131747, -16297398282, 32717680837], [8743476426082, -609627659778, 3895385620, 9381076166], [950824256966, 205535366319, -6805193392, 9477750519], [4751463708686, 330581638641, -13545556774, 16243419739], [17226159575590, -497834915853, 12857197992, 6455258675], [9184873170876, -338893142068, 3873790847, -13344930591], [17957803909152, 133367670196, 12394287574, 4092938778], [-9779892574074, 220632108648, 8978539716, 12612317856], [7274698502670, 666737089302, -14268018365, -32001093949], [18378067881474, 160261123872, -4292957200, -30485191792], [5379197674622, 1398195956777, -10360963232, -18755448139], [-5771843390572, -207553322965, -14809969183, -26142135502], [-319164471244, 711561266950, 29088817828, 12944699874], [9559609523712, 1344374708510, -2318656178, -29303921380], [8387511638648, -274912560007, -23769575559, 30744944528], [3301753466510, 650872167413, -1256283830, 23103539135], [35213931852920, -153400873780, -14141392666, -3603144846], [-15822143436502, -310242114454, 5355063685, -61821875347], [-21400992963926, -615520305732, -32089199704, -1927145172], [-2339291128754, 814545381210, 11366104494, 35579396580], [28078273541546, 111242711039, -36996269221, 22263348380], [15740335814000, -31751815221, 31307527802, -4939246167], [26199041559920, 1663576814822, -2861522223, -30375369071], [14038035496902, -1023852404862, -12122775168, 12476477282], [7693744869216, 728023834384, 6262789599, -50851472331], [3441042313570, 94728985322, 17241488716, 37936955026], [-18810797748616, -688270642858, 13477043174, 18755921828], [36542660769164, 1272295236569, 9751027390, -77531638337], [-8162728247896, 390587476820, -39311238314, -7999316618], [-4416577362988, -1139383334815, -24477444462, -76445016761], [4063529703120, -887974935756, -2522431248, -76721771820], [44257046766476, -24627604476, -20291998570, -6023079678], [-20835815599268, 747583340597, 30263247120, 14172575685], [-54980596008736, -350723871925, -15596729340, -12910379365], [42352772936450, 842168018293, 20228145370, 15177822995], [-16868561764386, 912150807258, -8906580276, -42627658642], [7110669574252, -1721491570471, 5459225182, -26774365621], [5952787316596, 589929337528, -36354275222, 20092199054], [-4319031250998, -2648312354976, 46554198324, -3823618124], [26881898472228, 2622759847278, -309075666, -91993966264], [-32153655035998, 903201490972, 37613142749, 53488688583], [-1892356192290, -2497086556235, 40863560470, -2506341365], [26057965246296, -827763527578, 13866794732, 17129375630], [10136114616478, -198784406698, -49819761456, 65410471582], [-24731807089266, -1173413434975, 16987379168, 34203343389], [6081689427192, 1938827741271, 7023948492, 80497948223], [-825822154782, 1568786774192, -28819178336, -22762340424], [-23495113172512, -862740765649, 36416024460, -61890090221], [-64955525093712, 508923200419, 31842758786, 89619388269], [-36615572046494, 133205179927, -74343473276, -15957071913], [-52314256417736, 1466175151003, -47309189012, -179406752677], [716110180724, -1727549623874, -50645267843, -29370986955], [-17000635696862, -1109644751134, -36608576641, 140945052795], [10098798057410, 1965259970140, -43276705074, 112518204646], [3470801202384, -170175353882, -46983077078, -92210746864], [-40761497511598, -700188600076, 23739389878, -102588278242], [7864193683232, 2440769012528, -50671227029, 144378717841], [18776729910442, -3573723573797, 103668556906, 83638891453], [-17430898726530, -2227973424562, -23193964874, -88918667352], [13176574615270, -263002441873, 6995147047, 171394172732], [-33856766680290, 5260912390586, -79994691454, -55829935480], [77382135475066, 652226342368, 4633396676, -56730877148], [-55299934498624, -301389638812, -50153247420, -79158693616], [-43003614408940, -4358934671676, 26895804998, 105420819366], [100170029564524, 2585949940674, -6198811238, -51559961776], [-20390734266474, 306906636058, 135178159266, 10930691160], [-30188937893192, -2364657185596, -51866804394, -56577027714], [92316534820886, -2628654983052, -102991961428, -12687103828], [-18560591695182, 3463854871153, -30974338754, 258542889371], [-6762582794728, -1863197852937, -87063373313, -127278984356], [-84754096250982, 1155068130470, -56005099320, -281318228730], [158884956874640, -1485773241792, 60543837753, 74090537203], [-93129644835502, 940716401104, -6071217554, -108489225638], [-38942736019700, -1140062653302, -201932025756, -88352164162], [17825788773600, 5651108543242, -99888758624, -32019824886], [-86884194460950, -663871791090, 178065846916, 37614919730], [-41829620133320, 2429735477235, 159170034450, 125469824141], [-61702817103264, -4006860147658, 118253801979, -109719003289], [77971644840356, 3805864448030, 112301629816, -105723664938], [-66743701639598, -458814610441, -28393622697, -288830700936], [-42176203171616, -3710210168633, -185166214352, 62789913191], [12256992180446, 6833508575775, -88996181735, -209291381942], [-68311555257448, -2752440824484, -106715618036, 270023072324], [138099575638382, -3009612688690, 45038704590, 172345170608], [74514976586724, -3680277923264, 90831909026, 98149098582], [-50439792447142, 1540638679659, -120349697362, -317783921047], [55180760159510, 2807471224506, -248365715228, -31518510770], [-170191957762972, -3483277783823, 4341384639, 202523731134], [152779244199538, 1210165345215, -96858242145, -72487447512], [92155572469312, 1382949218412, 149067899462, 218201693790], [-82182585662382, -2352123426509, -93984996510, -41518091], [123234083282890, 2947986378873, 1495398369, 85544624220], [-122578189939848, -2112247441120, 241390680968, 78130951216], [-120997613006478, -211635129490, -17005092648, 74338675214], [-12619836420916, -3868583424147, -155957457478, 180763680463], [-72215169111328, 13123501178608, -44926028074, 69318052674], [248543155111936, 2048248531876, 4188729034, 255011461834], [76612485966124, 1999447244200, -128577160156, -361604183704], [8851619801132, -793205219636, -192934509098, 232947696306], [-74810309182614, -636005305471, -147779092412, -341036372299], [-81628047376432, -869514027193, 94105906382, -7368943543], [-14156156458058, 1521666858468, -38115664604, -510698131284], [132956410564950, -13537283336845, 110842839540, -69191026521], [23227062354338, -6491069170920, -15434156604, -18060334020], [-118363031930782, -1075742822796, 182890580746, 344366552762], [-82518454544210, -7025977911543, -80939815137, 464342026378], [8752471008654, 5563618120036, 68561495392, 39836791988], [66619898836980, -7332054900488, 369886184, 95908643496], [32878139267202, -8083287249392, 37291213958, 248143160186], [260691069656054, -2851276538006, 8549850829, -420086434515], [174534205167656, -5091129716544, 65908226026, 10025831518], [203491394740358, -2288189240231, -260480944324, -38833922687], [-145163469426852, -3896721138859, -239208976808, -147387563451], [210550557640774, -12320059127640, -84941856437, -487941640363], [161713754901700, -16522039815643, 134790484532, 112921704397], [232619773232058, 11077868193389, 69751213015, -266362637398], [28628473062176, -56768649385, -73827255404, 455554351183], [-86219514126834, -9024544482996, -400563056252, 273218315900], [34693035740846, -12158886480533, -21351076044, 155125130111], [201943137194736, -5403804698001, -15761723453, -941174069168], [481502205111640, 2389539784743, -47025044354, -174512488799], [393575975811890, 2108630406697, 101015158426, -582218507393], [-127409959842718, -3892799785400, -315486499451, -380566913557], [154981878339660, -1400430881494, 513853389430, 667204563976], [302857328828818, 9424857491732, 129414766997, -52764253241], [311276464144044, -1808336266214, -181611036882, -611232158876], [206275731396430, -16250354484331, -436202341550, -386929278225], [-160703916805958, 5028773242594, -307515679152, -375913257374], [220623249016890, 2003454949088, -334787893160, 906822963656], [137973931314528, -18846011638970, 11500772574, -166790989700], [160562726425614, 6567203035161, -107564241986, 658371189599], [307430276879456, 4097310815632, -450010459206, -257231622726], [155866157909986, 10188841695483, 175986512202, -251671856155], [131185691969220, 11092659213685, 304260913054, 88650250975], [376624685621996, -1019415613216, 23453970534, 113335678866], [-68157334030160, 3507326137698, -17557234737, -305194493273], [140946142520442, -3085780683732, 669373734734, 658123123246], [283459481635892, 6278375508113, 108957951477, -238656414040], [245678743605044, -4537701194266, 214927478341, 312554127925], [38761906607054, -12374432125892, -597912377492, -586248058364], [-168789420614776, 2905404708851, -64060080084, -49955981629], [-110133454670016, 5903924593122, -38344476606, -471925358208], [-276163222959240, 5014835668965, 1611763993, -25976276844], [183524158660524, 9880792653348, 7846224248, 546513896872], [-329349900606688, -15734365667625, -162343093744, 1503892592543], [654286222248702, 5165825008126, -70893342436, 434152031514], [285735998396008, 4658577516660, -424332048725, -770476546803], [23549800267814, 12804165619642, -265085280516, 726696747414], [35007013398684, -13253952842708, -426862725066, 166225573938], [5884549082384, 27035585648482, -330305366486, -819046042072], [-209987618896162, -24730070200778, 132373537875, -421068654973], [-143386051968848, -3359055982629, 392981399979, -644182547468], [-281192718406260, 7747383279718, 273122299544, 1653492328906], [-330743159892266, 23085700515109, 672242013684, 747647747669], [24425204454584, -22630436280178, 153939789564, -684976347090], [-405418368884958, -6313140377368, -246946012928, 931391504568], [41628711150506, 11944259046955, -261008784290, 1646497250977], [609013923938756, 1413400853061, 633636540636, 768909585441], [306196232538564, -14113821532444, 381312293841, -1065738460497], [-78342947841020, -19463057783935, -51925233028, -1440368799411], [-824161864027930, 20736647380917, 76839043698, 530085223151], [-299819812643408, 33696678127983, -334281022600, -621701388541], [107341489865950, -20796768966738, -205579910572, 818243219962], [149758855536086, 27632724850447, 680140154136, 118778792831], [-204503481819438, 19776919360825, 880538225316, 756533063197], [-65086310997622, -18463782027228, -10387391126, -1590960549838], [122014342531492, 31089919773352, 374195535388, -683192401280], [362059425635652, 3015370078316, -799946995305, 496247556521], [151500186562034, 41540082691108, -234020261851, 143202445383], [541710610796410, 25390739919392, -624823495224, 203471500000], [-87507881901450, 11119235419595, 598646509495, 1006259646792], [-350997353103130, -15973257000670, 218550254678, 636903311372], [228302678463206, 17281745633570, 510918027712, 1667040430290], [-1265107480701848, -7664389258764, -348674447204, -350719127416], [924933482072624, 12044583599629, 290447445735, 337394668526], [169539472605542, -27829477060702, 656953410438, 1638994855508], [-201248611763888, -26890143871274, -151255627984, -387930019806], [356288041858840, 1516122766798, -615195663148, 1263619316450], [-323150916824058, -22280104343273, -460459282660, 607729723363], [-503432039583584, -4393305395521, -333814838939, -1313243111842], [1235109000912670, 14448893833768, 209585594440, 982258103376], [1090204273861152, 12505483910907, 134800388951, 425754240712], [380870647126960, 12368815524636, -420276800265, -1271529008391], [-626904569392288, -33101949223834, -314455315292, 1628252344458], [542371160685960, -31214944907298, -401941442814, -1809869950816], [-284835512043256, -40127142423858, 182888878372, 1243891794570], [10842616723578, -1569095618326, 369309464452, 1935650324886], [536869715305244, 24583111359221, 1227397763554, -761732710673], [943413982782882, -1773398435632, 732931166518, -353148289086], [-1187735269035276, 5550914815194, 716990088282, 559224639800], [1364466488718420, -2867003085967, -501560447180, -540150045723], [-66782288929200, -19950571078439, -1759889394923, 278495524260], [1228722689184706, -28336831301468, 6433629308, -1794200979432], [-266486715781008, 30915533545468, -524551212368, -11581305384], [1083506785495912, -4406564192201, 766474974487, 1772753643372], [141820718637862, 18466051399933, 1174648976645, -2214714720368], [1116588200330672, -3376183015957, 814424357268, 2359660964975], [-520621917678558, 3706470329893, -4307257340, -1871651799183], [-454520942442008, -18516128145748, -716602424522, 1691105217030], [-143567385249206, 20157423278924, -575495269346, -1939044862530], [-452141898272558, -23529637710363, 221229939369, -1498680065336], [-119942542699854, 5371204056116, 1613075037446, 654705351262], [-91674757291220, -18862338533327, 628578562360, 1574678526269], [-75214050135864, 264305162652, 1935294130724, -142331582496], [-342768932712814, -2783830407854, -66895034016, -75738148022], [114411612661060, 2432371313049, 1080700758924, -893597358335], [-1219956778955756, -51922461326330, -555885031258, 853281373056], [-1095909659193300, -18764512074376, -73650394088, -174613288300], [1009437742013700, -20376855399729, 875360886925, 507856548026], [-1369383551975746, -6332301435217, -705380377154, 540985609], [-1341495406019820, 25239977408217, -188625177156, -590421472715], [-565381091709906, 26762270326808, -389262066532, 2572924029640], [387394939795574, 1543159747287, -1541643152762, -2447614830279], [-618132436590382, 52742975875147, 163578298901, -391450267530], [-435193679756728, -43676573009418, -527255978750, 3165990534044], [119625370417818, 39921810690464, -225612847474, -3282021869646], [16516217409294, -79964727043854, 1160151835056, 1263293553770], [732950072227760, -407263033664, 731735188308, -134896515268], [-1058688083520878, 69746253927068, -1434263617032, -1836181017116], [58673357889030, 58640226079577, 104055923375, 3851423951106], [-1343199488855546, -39551081379609, -528849879205, -1837615317128], [-330443930633498, 7184538728631, 180675128450, 2657942496677], [-811862085504668, -46147051496855, -47335571346, 2014051759583], [-287545138631884, -33344002503674, -1347424573757, -4417013342353], [275441790882568, -78873540767445, -166159494686, -560910716455], [1678823475949480, -12978240071458, -61830144016, 1721919759226], [-2662949964672588, -16911389820820, -445742456153, 84521636513], [-365842513150762, 35708668511766, 1813652199077, 2551451664561], [-1396813282640282, 41053356840788, 2767713936244, 1413886172028], [1098023335696274, -57864175524624, -23090218957, 52680986389], [-972864431836778, -8458432296006, -380094149608, -2979789983966], [205449223117004, 4422680766127, 1926676968529, 2020906293926], [519115359087336, 27597640981736, -156562155574, -3286479063754], [2143923816663384, 36303107817557, 1884583643235, 2019423986882], [1084068748970750, -37856576553061, -310578868603, 49514499138], [-789239305339554, 16151028732373, 2100424457588, 2257005094573], [1070846212969964, -18140948131950, 2696017797994, 3507191948468], [-811281222786306, 71393950639596, 749934913345, -260206589117], [1368556419201578, 55946031658365, -1047893838156, 1778236666233], [2222484257497366, -92701393867631, 189939951862, -2740644674241], [-470302717286158, -72717001657896, 120857142812, -3679735259180], [780994108251186, -5824604908076, -1482858849632, 423219575396], [-720674410851982, -27183464945013, -311245983839, 4277918078962], [-747715366001356, 63914288972988, 154661943370, 711632372474], [-2929418564518916, -41499803138352, 1200997833525, -1666452807753], [2751915284146594, 58069010776404, -771873196808, -72285049348], [440971978357068, 12805581375906, 1377330571407, -6252229800225], [2573060753779042, 19641027734962, -254226844668, 1492529481890], [174378368280700, 58312393036284, 2615357332684, 5240718484620], [277292733862148, 127305246665949, -652299232840, -1868795088007], [-264518793623204, -26158728048371, 1522993028670, 6904668544583], [3150565436671820, 18077204950755, -288604814247, 348317341506], [361211541286992, -136961988795252, 617657138668, 1406015204904], [2339657453743620, 30898424920733, -2922545819674, -983596690757], [1035575128593186, -81110499785012, 1416355660552, -3668875525300], [34767073493916, 53615786222886, 1833997806919, 3796957059763], [90550302281848, 79157360953195, -2117688067214, -1524495753991], [-833062975077194, -70696298661530, 896390914144, 5047811212494], [-640131802375280, -37568570571094, -803534085632, -8108609550254], [-1457393390202336, -5734477466570, -2249007413026, -4198339460], [1645523637322702, -107556751570110, 359508427411, -3560861224417], [-875199715260928, -79304707233489, 2976302844469, -4414110690674], [-913531381547010, -53529330606983, -2538397423888, -3516768386139], [-2096946035043388, -24639318355312, -885510149338, 1373047056566], [2144891119983502, -13172576949794, 1614789148820, 287756029706], [1365194014270530, -889867467784, -3761501209204, -2201546523492], [-140885225887892, 76561636693600, 1296038967689, 5361005791963], [1523535050661140, 113783309134454, 4643780870, -3157517193480], [5179612864804772, 13370341191517, -235754083144, 1300492436097], [1337398644170694, 173867807909821, 970195817574, -4233028200085], [-1292053722993444, 29601455385701, 1579845918482, 9689460139415], [-1290736856441294, 59857054745742, -655707898235, -4148105595007], [33773295054618, 46376040543261, 777859187346, -2200694998253], [1693551709529304, 125748144788186, 2912024682654, 2260878233488], [-333413473410634, 187307057719082, -2854370310287, 2287796974377], [1226778439104426, 64384120725968, -3412351218706, -1939950075102], [823142944456118, -83019231699471, -2197900849618, -337007262457], [-1579143151211334, -431188768348, 2565250346836, -846690325336], [-1036574741267066, -36965102960285, -4193752580821, -1077405650140], [4330635980946724, 20119441159782, 407184216682, 2201735464436]]
